betty.cli.error module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.cli.error module

Command Line Interface error handling.

betty.cli.error.user_facing_error_to_bad_parameter(localizer: Localizer = <betty.locale.localizer.Localizer object>) → Iterator[None]

  Convert a `betty.error.UserFacingError` exception to a `click.BadParameter` exception.